@@ -59,11 +59,20 @@ sub get_communities {
     foreach my $stanza (@$config) {
       if ($stanza->{tag} and $stored_tag eq $stanza->{tag}) {
         push @communities, {%$stanza, only => [$device->ip]};
+        ++$seen_tags->{ $stored_tag };
         last;
       }
     }
   }
 
+  # clean the community table of obsolete tags
+  eval { $device->community->update({$tag_name => undef}) }
+    if $device->in_storage
+       and (not $stored_tag or !exists $seen_tags->{ $stored_tag });
+
+  # make sure all tagged will come before legacy communities
+  push @communities, @$config;
+
   # try last-known-good v2 read
   push @communities, {
     read => 1, write => 0, driver => 'snmp',
@@ -79,12 +88,7 @@ sub get_communities {
     community => $snmp_comm_rw,
   } if $snmp_comm_rw and $mode eq 'write';
 
-  # clean the community table of obsolete tags
-  eval { $device->community->update({$tag_name => undef}) }
-    if $device->in_storage
-       and (not $stored_tag or !exists $seen_tags->{ $stored_tag });
-
-  return ( @communities, @$config );
+  return @communities;
 }
 
 =head2 snmp_comm_reindex( $snmp, $device, $vlan )
